Installation
============

Before installing Qililab it is recommended to create a virtual environment to use for the library installation, to do it so
please run:

.. code-block:: console

    $ python3 -m venv .venv

and activate it like this:

.. code-block:: console

    $ source .venv/bin/activate

To install Qililab, please run:

.. code-block:: console

    $ pip install qililab

This will install all necessary dependencies to start using Qililab.

